==> nodejs_interop-0.7.0.tar.gz: test/node/process/process_test.dart <==
import 'dart:async';
import 'dart:js_util';
import 'package:js/js.dart';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:path/path.dart' as path;
import 'package:pub_semver/pub_semver.dart';
import 'package:test/test.dart';

/// Tests the features of the [NodeProcess] class.
void main() => group('NodeProcess', () {
  final isMacOS = process.platform == 'darwin';
  final isWindows = process.platform == 'win32';
  final nodeVersion = new Version.parse(process.version.substring(1));

  group('.arch', () {
    test('should return the processor architecture', () {
      expect(process.arch, equals('x64'));
    });
  });

  group('.argv', () {
    test('should return the command line arguments', () {
      expect(process.argv, isNotEmpty);
      expect(process.argv[0], endsWith(isWindows ? r'\node.exe' : '/node'));
    });
  });

  group('.argv0', () {
    test('should return the original value of `argv[0]`', () {
      expect(process.argv0, equals(isWindows ? 'node.exe' : 'node'));
    });
  });

  group('.config', () {
    test('should return the configure options used to compile Node.js', () {
      var targetDefaults = getProperty(process.config, 'target_defaults');
      expect(getProperty(targetDefaults, 'default_configuration'), equals('Release'));

      var variables = getProperty(process.config, 'variables');
      expect(getProperty(variables, 'target_arch'), equals('x64'));
    });
  });

  group('.env', () {
    test('should return an object containing the user environment', () {
      expect(hasProperty(process.env, 'HOME'), isTrue);
      expect(hasProperty(process.env, 'PATH'), isTrue);
    });

    test('should allow the creation and deletion of an environment variable', () {
      setProperty(process.env, '__TEST__', 'test');
      expect(getProperty(process.env, '__TEST__'), equals('test'));
      Reflect.deleteProperty(process.env, '__TEST__');
      expect(hasProperty(process.env, '__TEST__'), isFalse);
    });

    test('should be case-insensitive on Windows, case-sensitive on other platforms', () {
      expect(getProperty(process.env, 'home'), isWindows ? isNotEmpty : isNull);
    });
  });

  group('.execArgv', () {
    test('should return the set of Node.js-specific command-line options passed', () {
      expect(process.execArgv, isEmpty);
    });
  });

  group('.execPath', () {
    test('should return the absolute pathname of the executable that started the process', () {
      expect(process.execPath, endsWith(isWindows ? r'\node.exe' : '/node'));
      expect(path.isAbsolute(process.execPath), isTrue);
    });
  });

  group('.exitCode', () {
    test('should get or set the process exit code', () {
      process.exitCode = 1;
      expect(process.exitCode, equals(1));
      process.exitCode = 0;
      expect(process.exitCode, equals(0));
    });
  });

  group('.mainModule', () {
    test('should be the same value as `require.main`', () {
      expect(process.mainModule, equals(require.main));
      expect(process.mainModule.id, equals('.'));
    });

    test('should not have a parent module', () {
      expect(process.mainModule.parent, isNull);
    });
  });

  group('.pid', () {
    test('should return the PID of the current process', () {
      expect(process.pid, isPositive);
    });

    test('should be different from the PID of the parent process', () {
      expect(process.pid, isNot(equals(process.ppid)));
    }, skip: nodeVersion < new Version(9, 2, 0));
  });

  group('.platform', () {
    test('should return a string identifying the operating system platform', () {
      expect(process.platform, equals(isWindows ? 'win32' : (isMacOS ? 'darwin' : 'linux')));
    });
  });

  group('.ppid', () {
    test('should return the PID of the current parent process', () {
      expect(process.ppid, allOf(isPositive, isNot(equals(process.pid))));
    });
  }, skip: nodeVersion < new Version(9, 2, 0));

  group('.release', () {
    test('should return an object containing metadata related to the current release', () {
      expect(process.release.name, equals('node'));
      expect(process.release.headersUrl, startsWith('https://nodejs.org/download/release/'));
      expect(process.release.sourceUrl, startsWith('https://nodejs.org/download/release/'));
    });
  });

  group('.stderr', () {
    test('should return a `Writable` stream', () {
      expect(process.stderr, const isInstanceOf<Writable>());
    });
  });

  group('.stdin', () {
    test('should return a `Readable` stream', () {
      expect(process.stdin, const isInstanceOf<Readable>());
    });
  });

  group('.stdout', () {
    test('should return a `Writable` stream', () {
      expect(process.stdout, const isInstanceOf<Writable>());
    });
  });

  group('.title', () {
    test('should return the string "node" by default', () {
      expect(process.title, equals('node'));
    });

    test('should properly set a new process title', () {
      process.title = 'dart';
      expect(process.title, equals('dart'));
    });
  });

  group('.version', () {
    test('should return a string formatted like "vX.Y.Z"', () {
      expect(process.version, matches(new RegExp(r'^v\d+(\.\d+){2}$')));
    });
  });

  group('.versions', () {
    test('should return an object listing the version strings of Node.js and its dependencies', () {
      for (var lib in const ['node', 'uv', 'v8']) expect(getProperty(process.versions, lib), matches(new RegExp(r'^(\d+\.){2,}')));
    });
  });

  group('.chdir()/.cwd()', () {
    test('should get or set the current working directory', () {
      expect(process.cwd(), endsWith(isWindows ? r'\nodejs-interop.dart' : '/nodejs-interop.dart'));
      process.chdir('node_modules');
      expect(process.cwd(), endsWith(isWindows ? r'\nodejs-interop.dart\node_modules' : '/nodejs-interop.dart/node_modules'));
      process.chdir('..');
      expect(process.cwd(), endsWith(isWindows ? r'\nodejs-interop.dart' : '/nodejs-interop.dart'));
    });
  });

  group('.cpuUsage()', () {
    test('should return the user and system CPU time usage', () {
      var usage = process.cpuUsage();
      expect(usage.system, isPositive);
      expect(usage.user, isPositive);
    });
  });

  group('.getegid()', () {
    test('should return the effective numeric group identity', () {
      expect(process.getegid(), isPositive);
    });
  });

  group('.geteuid()', () {
    test('should return the effective numeric user identity', () {
      expect(process.geteuid(), isPositive);
    });
  });

  group('.getgid()', () {
    test('should return the numeric group identity', () {
      expect(process.getgid(), isPositive);
    });
  });

  group('.getgroups()', () {
    test('should return a list with the supplementary group identifiers', () {
      expect(process.getgroups(), isNotEmpty);
    });
  });

  group('.getuid()', () {
    test('should return the numeric user identity', () {
      expect(process.getuid(), isPositive);
    });
  });

  group('.hasUncaughtExceptionCaptureCallback()/.setUncaughtExceptionCaptureCallback()', () {
    test('should set or unset an uncaught exception callback', () {
      expect(process.hasUncaughtExceptionCaptureCallback(), isFalse);
      process.setUncaughtExceptionCaptureCallback(allowInterop((error) => null));
      expect(process.hasUncaughtExceptionCaptureCallback(), isTrue);
      process.setUncaughtExceptionCaptureCallback(null);
      expect(process.hasUncaughtExceptionCaptureCallback(), isFalse);
    });
  }, skip: nodeVersion < new Version(9, 3, 0));

  group('.hrtime()', () {
    test('should return the current high-resolution real time', () {
      var hrtime = process.hrtime();
      expect(hrtime, hasLength(2));
      expect(hrtime.first, isPositive);
      expect(hrtime.last, isPositive);
    });

    test('should allow diff from a previous call', () async {
      var previousHrtime = process.hrtime();
      var hrtime = await new Future.delayed(const Duration(seconds: 1), () => process.hrtime(previousHrtime));
      expect(hrtime, hasLength(2));
      expect(hrtime.first, isPositive);
      expect(hrtime.last, isPositive);
    });
  });

  group('.kill()', () {
    test('should send a signal to the process with the specified PID', () async {
      var completer = new Completer();
      process..on('SIGUSR2', allowInterop((signal) => completer.complete(signal)))..kill(process.pid, 'SIGUSR2');
      expect(await completer.future, equals('SIGUSR2'));
    });

    test('should return normally if the specified PID exists', () {
      expect(() => process.kill(process.pid, 0), returnsNormally);
    });

    test('should throw an error if the specified PID does not exist', () {
      expect(() => process.kill(-1024, 'SIGUSR2'), throwsException);
    });
  });

  group('.memoryUsage()', () {
    test('should return an object describing the memory usage', () {
      var usage = process.memoryUsage();
      expect(usage.external, isPositive);
      expect(usage.heapUsed, greaterThan(usage.external));
      expect(usage.heapTotal, greaterThan(usage.heapUsed));
      expect(usage.rss, greaterThan(usage.heapTotal));
    });
  });

  group('.nextTick()', () {
    test('should add the given callback to the "next tick queue"', () async {
      var completer = new Completer();
      process.nextTick(allowInterop((arg) => completer.complete(arg)), 'OK');
      expect(await completer.future, equals('OK'));
    });
  });

  group('.umask()', () {
    var defaultUmask = int.parse('022', radix: 8);
    process.umask(defaultUmask);

    test('should return the octal number `022` by default', () {
      expect(process.umask(), equals(defaultUmask));
    });

    test('should properly set a new file mode creation mask and return the previous one', () {
      var newUmask = int.parse('077', radix: 8);
      expect(process.umask(newUmask), defaultUmask);
      expect(process.umask(), equals(newUmask));
    });
  });

  group('.uptime()', () {
    test('should return a positive number', () {
      expect(process.uptime(), isPositive);
    });
  });
});

==> nodejs_interop-0.8.0.tar.gz: test/node/process/process_test.dart <==
import 'dart:async';
import 'dart:js';
import 'package:nodejs_interop/js.dart';
import 'package:nodejs_interop/node.dart';
import 'package:path/path.dart' as path;
import 'package:pub_semver/pub_semver.dart';
import 'package:test/test.dart';

/// Tests the features of the [Process] class.
void main() => group('Process', () {
  final isMacOS = process.platform == 'darwin';
  final isWindows = process.platform == 'win32';
  final nodeVersion = new Version.parse(process.version.substring(1));

  group('.arch', () {
    test('should return the processor architecture', () {
      expect(process.arch, equals('x64'));
    });
  });

  group('.argv', () {
    test('should return the command line arguments', () {
      expect(process.argv, isNotEmpty);
      expect(process.argv[0], endsWith(isWindows ? r'\node.exe' : '/node'));
    });
  });

  group('.argv0', () {
    test('should return the original value of `argv[0]`', () {
      expect(process.argv0, equals(isWindows ? 'node.exe' : 'node'));
    });
  });

  group('.config', () {
    test('should return the configure options used to compile Node.js', () {
      var targetDefaults = getProperty(process.config, 'target_defaults');
      expect(getProperty(targetDefaults, 'default_configuration'), equals('Release'));

      var variables = getProperty(process.config, 'variables');
      expect(getProperty(variables, 'target_arch'), equals('x64'));
    });
  });

  group('.env', () {
    test('should return an object containing the user environment', () {
      expect(hasProperty(process.env, 'HOME'), isTrue);
      expect(hasProperty(process.env, 'PATH'), isTrue);
    });

    test('should allow the creation and deletion of an environment variable', () {
      setProperty(process.env, '__TEST__', 'test');
      expect(getProperty(process.env, '__TEST__'), equals('test'));
      deleteProperty(process.env, '__TEST__');
      expect(hasProperty(process.env, '__TEST__'), isFalse);
    });

    test('should be case-insensitive on Windows, case-sensitive on other platforms', () {
      expect(getProperty(process.env, 'home'), isWindows ? isNotEmpty : isNull);
    });
  });

  group('.execArgv', () {
    test('should return the set of Node.js-specific command-line options passed', () {
      expect(process.execArgv, isEmpty);
    });
  });

  group('.execPath', () {
    test('should return the absolute pathname of the executable that started the process', () {
      expect(process.execPath, endsWith(isWindows ? r'\node.exe' : '/node'));
      expect(path.isAbsolute(process.execPath), isTrue);
    });
  });

  group('.exitCode', () {
    test('should get or set the process exit code', () {
      process.exitCode = 1;
      expect(process.exitCode, equals(1));
      process.exitCode = 0;
      expect(process.exitCode, equals(0));
    });
  });

  group('.mainModule', () {
    test('should be the same value as `require.main`', () {
      expect(process.mainModule, equals(require.main));
      expect(process.mainModule.id, equals('.'));
    });

    test('should not have a parent module', () {
      expect(process.mainModule.parent, isNull);
    });
  });

  group('.pid', () {
    test('should return the PID of the current process', () {
      expect(process.pid, isPositive);
    });

    test('should be different from the PID of the parent process', () {
      expect(process.pid, isNot(equals(process.ppid)));
    }, skip: nodeVersion < new Version(9, 2, 0));
  });

  group('.platform', () {
    test('should return a string identifying the operating system platform', () {
      expect(process.platform, equals(isWindows ? 'win32' : (isMacOS ? 'darwin' : 'linux')));
    });
  });

  group('.ppid', () {
    test('should return the PID of the current parent process', () {
      expect(process.ppid, allOf(isPositive, isNot(equals(process.pid))));
    });
  }, skip: nodeVersion < new Version(9, 2, 0));

  group('.release', () {
    test('should return an object containing metadata related to the current release', () {
      expect(process.release.name, equals('node'));
      expect(process.release.headersUrl, startsWith('https://nodejs.org/download/release/'));
      expect(process.release.sourceUrl, startsWith('https://nodejs.org/download/release/'));
    });
  });

  group('.title', () {
    test('should return the string "node" by default', () {
      expect(process.title, equals('node'));
    });

    test('should properly set a new process title', () {
      process.title = 'dart';
      expect(process.title, equals('dart'));
    });
  });

  group('.version', () {
    test('should return a string formatted like "vX.Y.Z"', () {
      expect(process.version, matches(new RegExp(r'^v\d+(\.\d+){2}$')));
    });
  });

  group('.versions', () {
    test('should return an object listing the version strings of Node.js and its dependencies', () {
      for (var lib in const ['node', 'uv', 'v8']) expect(getProperty(process.versions, lib), matches(new RegExp(r'^(\d+\.){2,}')));
    });
  });

  group('.chdir()/.cwd()', () {
    test('should get or set the current working directory', () {
      expect(process.cwd(), endsWith('nodejs-interop.dart'));
      process.chdir('node_modules');
      expect(process.cwd(), endsWith(path.join('nodejs-interop.dart', 'node_modules')));
      process.chdir('..');
      expect(process.cwd(), endsWith('nodejs-interop.dart'));
    });
  });

  group('.cpuUsage()', () {
    test('should return the user and system CPU time usage', () {
      var usage = process.cpuUsage();
      expect(usage.system, isPositive);
      expect(usage.user, isPositive);
    });
  });

  group('.getegid()', () {
    test('should return the effective numeric group identity', () {
      expect(process.getegid(), isPositive);
    });
  });

  group('.geteuid()', () {
    test('should return the effective numeric user identity', () {
      expect(process.geteuid(), isPositive);
    });
  });

  group('.getgid()', () {
    test('should return the numeric group identity', () {
      expect(process.getgid(), isPositive);
    });
  });

  group('.getgroups()', () {
    test('should return a list with the supplementary group identifiers', () {
      expect(process.getgroups(), isNotEmpty);
    });
  });

  group('.getuid()', () {
    test('should return the numeric user identity', () {
      expect(process.getuid(), isPositive);
    });
  });

  group('.hasUncaughtExceptionCaptureCallback()/.setUncaughtExceptionCaptureCallback()', () {
    test('should set or unset an uncaught exception callback', () {
      expect(process.hasUncaughtExceptionCaptureCallback(), isFalse);
      process.setUncaughtExceptionCaptureCallback(allowInterop((error) => null));
      expect(process.hasUncaughtExceptionCaptureCallback(), isTrue);
      process.setUncaughtExceptionCaptureCallback(null);
      expect(process.hasUncaughtExceptionCaptureCallback(), isFalse);
    });
  }, skip: nodeVersion < new Version(9, 3, 0));

  group('.hrtime()', () {
    test('should return the current high-resolution real time', () {
      var hrtime = process.hrtime();
      expect(hrtime, hasLength(2));
      expect(hrtime.first, isPositive);
      expect(hrtime.last, isPositive);
    });

    test('should allow diff from a previous call', () async {
      var previousHrtime = process.hrtime();
      var hrtime = await new Future<List<int>>.delayed(const Duration(seconds: 1), () => process.hrtime(previousHrtime));
      expect(hrtime, hasLength(2));
      expect(hrtime.first, isPositive);
      expect(hrtime.last, isPositive);
    });
  });

  group('.kill()', () {
    test('should send a signal to the process with the specified PID', () async {
      var completer = new Completer<String>();
      process..on('SIGUSR2', allowInterop((signal) => completer.complete(signal)))..kill(process.pid, 'SIGUSR2');
      expect(await completer.future, equals('SIGUSR2'));
    });

    test('should return normally if the specified PID exists', () {
      expect(() => process.kill(process.pid, 0), returnsNormally);
    });

    test('should throw an error if the specified PID does not exist', () {
      expect(() => process.kill(-1024, 'SIGUSR2'), throwsException);
    });
  });

  group('.memoryUsage()', () {
    test('should return an object describing the memory usage', () {
      var usage = process.memoryUsage();
      expect(usage.external, isPositive);
      expect(usage.heapUsed, greaterThan(usage.external));
      expect(usage.heapTotal, greaterThan(usage.heapUsed));
      expect(usage.rss, greaterThan(usage.heapTotal));
    });
  });

  group('.nextTick()', () {
    test('should add the given callback to the "next tick queue"', () async {
      var completer = new Completer<String>();
      process.nextTick(allowInterop((arg) => completer.complete(arg)), 'OK');
      expect(await completer.future, equals('OK'));
    });
  });

  group('.umask()', () {
    var defaultUmask = int.parse('022', radix: 8);
    process.umask(defaultUmask);

    test('should return the octal number `022` by default', () {
      expect(process.umask(), equals(defaultUmask));
    });

    test('should properly set a new file mode creation mask and return the previous one', () {
      var newUmask = int.parse('077', radix: 8);
      expect(process.umask(newUmask), defaultUmask);
      expect(process.umask(), equals(newUmask));
    });
  });

  group('.uptime()', () {
    test('should return a positive number', () {
      expect(process.uptime(), isPositive);
    });
  });
});
